===========
 Changelog
===========

3.4 (2019-12-30)
================

- On mobile devices:

    + fix rendering of the calendar by replacing the tabular rendering by a
      vertical one like the print version.

    + replace secondary horizontal menu with a vertical one hidden behind a
      burger icon.

3.3 (2019-10-01)
================

- Consider customization of pre-defined fields in forms.

- Update the ZCML configuration and CSS to changes in
  `icemac.addressbook >= 9`.


3.2 (2018-10-13)
================

- Drop dependency on `decorator` package.

- Update to changes in test infrastructure in `icemac.addressbook >= 8.0`.

- Change installation procedure from `bootstrap.py` to `virtualenv`,
  see `README.txt`.


Older versions
==============

See `OLD_CHANGES.rst`_.

.. _`OLD_CHANGES.rst` : https://bitbucket.org/icemac/icemac.ab.calendar/raw/default/OLD_CHANGES.rst
